{% extends "dashboard_app/_content.html" %}

{% block content %}
<h1>TODO</h1>
<ul>
  <li>Briefly mention key dashboard features</li>
  <li>Link to readthedocs dashboard manual</li>
  <li>Add sensible dashboard index page (recent/interesting stuff)</li>
</ul>
{% endblock %}
